==> korweblog-1.5.8.tar.gz: korweblog-1.5.8/user.php <==
<?
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001,2002 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

include ("include/common.inc.php");
include ("include/posted.inc.php");

$check = array("infochange","mark","bmark","logout","passchange");
if (!isset($_COOKIE['kwebloguser']) || !$login) {
   if (in_array($what, $check)) KWL_ShowError(_USER_ONLY);
   KWL_Redirect("login.php");
}

if ($CONF['User_list']) {
   include("$CONF[G_PATH]/include/kmod/user_list/index.php");
}

$out = new KWL_Html;
settype($what, "string");
switch ($what) {
   
   case "infochange":
      if (KWL_HcodeCheck($uid.$what,$hcode)) {
         $email = KWL_EmailCheck($email);
         if (!$email) KWL_ShowError(_HID);
         $url = KWL_UrlCheck($url);
         $sig = trim($sig);
         $profile = trim($profile);
         $sql = "UPDATE T_Users SET email = '$email' , url = '$url', user_sig = '$sig' , profile = '$profile' WHERE uid = '$uid'";
         if (SqlQuery($sql)) KWL_Redirect("user.php",1);
         else KWL_ShowError(_SQL_ERROR);
      } else KWL_ShowError(_SQL_ERROR);
   break;

   case "mark":
      if ($rid) {
         if (KWL_BookmarkSave($user['uid'],$rid)) KWL_ShowError(_BOOKMARK_SAVED);
         else KWL_ShowError(_BOOKMARK_ERROR);
      } else KWL_Redirect("login.php");
   break;

   case "bmark":
      if (isset($delid)) {
         $sql = "DELETE FROM T_UBookmark WHERE id='$delid'";
         if (SqlQuery($sql)) $msg = _BOOKMARK_DELETED;
         else  $msg = _SQL_ERROR;
      }
      include("include/header.inc.php");
      KWL_UserNavig();
      unset($VAR);
      $result = KWL_BookmarkList($user['uid'],1);
      $VAR['Content'] = "<BR>". $out->table_start("100%");
      if (mysql_num_rows($result)) {
         $num = 1;
         while ($A = mysql_fetch_array($result)) {
            if ($A['pid'] == "story") $sql = "SELECT Rid,Heading,Author,Birthstamp FROM T_Stories ";
            else $sql = "SELECT Content,Author,Birthstamp FROM T_Comments ";
            $sql .= "WHERE Rid='$A[rid]'";
            $C = SqlQueryFetchArray($sql);
            
            $VAR['Content'] .= "<TR><TD>$num. ";
            if (is_array($C)) {
               if ($C['Author'] == "Anonymous") $C['Author'] = _ANONY;
               if ($A['pid'] == "story") {
                  $VAR['Content'] .= "<A HREF=\"". KWL_MakeStoryLink($A['rid']) ."\">$C[Heading]</A>";
               } else {
                  $VAR['Content'] .= "<A HREF=\"comments.php?rid=$A[pid]&amp;bid=$A[rid]&amp;bm=1#$A[rid]\">". KWL_PrepareHtml(KWL_StringCut($C['Content'],50)) . "...</A>";
               }
               $VAR['Content'] .= " - <FONT SIZE=\"-1\">$C[Author] (" .
                                  KWL_DateFormat($C['Birthstamp'],"%b-%d %I:%M %p") .")</FONT>";
            } else $VAR['Content'] .= _REPLY_DELETED;
            $VAR['Content'] .= "</TD><TD ALIGN=CENTER><A HREF=\"user.php?what=bmark&delid=$A[id]\">". _BOOKMARK_DEL ."</A></TD></TR>\n";
            $num++;
         }
         
      } else $VAR['Content'] .= "<TR><TD>". _NO_BOOKMARK ."</TD></TR>";
      $VAR['Content'] .= "<TR><TD COLSPAN=2 ALIGN=CENTER><HR SIZE=1 WIDTH=80% NOSHADE>" . sprintf(_BOOKMARK_NUM,$CONF['Bmark_limit']) ."</TD></TR>". $out->table_end();
      $VAR['Heading'] = _BOOKMARK;
      KWL_DrawMain($VAR);
      include("include/footer.inc.php");
      exit;
   break;

   case "logout":
      setcookie("kwebloguser","");
      KWL_RedirectNotice(sprintf(_START_LOGOUT,$user['name']),"$CONF[G_URL]",1);
   break;

   case "passchange":
      if (!empty($pass1) && !empty($pass2) && KWL_HcodeCheck($uid.$what,$hcode)) {
         if ($pass1 == $pass2) {
            $cpass = crypt($pass1);
            $sql = "UPDATE T_Users SET pass = '$cpass' WHERE uid = '$uid'";
            if (SqlQuery($sql)) {
               setcookie("kwebloguser","");
               KWL_RedirectNotice(sprintf(_PASS_CHANGED,$user['name']),"login.php",3);
            } else KWL_ShowError(_SQL_ERROR);
         } else KWL_ShowError(_NO_CHANGE);
      } else KWL_ShowError(_NO_CHANGE);
   break;

   case "userlist":
      if ($CONF['User_list']) {
         include("include/header.inc.php");
         KWL_UserNavig();
         settype($index, "string");
         settype($where, "string");
         KWL_UserList($index,"$CONF[G_URL]/user.php?what=userlist&index=$index",$where,$out);
         include("include/footer.inc.php");
         exit;
      } else KWL_ShowError(_DISABLED);
   break;

   case "mypost":
      include("include/header.inc.php");
      KWL_UserNavig();
      $my = new KWL_MyPost;
      $my->my_story($user['name'],$user['email'],$out);
      $my->my_reply($user['name'],$user['email'],$out);
      include("include/footer.inc.php");
      exit;
   break;

   default: 

$head = _UHOME;
include("include/header.inc.php");
KWL_UserNavig();
$VAR['Heading'] = _USER_INFO;
$VAR['Content'] = $out->form_start("user.php","change")
. $out->table_start("100%",'',0,0,3) ."
<TR>
   <TD>". _NAME .": </TD>
   <TD><A HREF=\"profiles.php?uid=$user[uid]\">$user[name]</A> (#$user[uid])</TD>
</TR>
<TR>
   <TD>". _EMAIL .": </TD>
   <TD>". $out->input_form("TEXT","email",$user['email'],KWL_FormSize(10),60) ."</TD>
</TR>
<TR>
   <TD>". _URL .": </TD>
   <TD>". $out->input_form("TEXT","url",$user['url'],KWL_FormSize(15),100) ."</TD>
</TR>
<TR>
   <TD>". _RDATE .": </TD>
   <TD>$user[rdate]</TD>
</TR>
<TR>
   <TD COLSPAN=2>". _USER_SIG .":<BR>
   ". $out->textarea("sig",4,$size['text'],KWL_PrepareHtml($user['user_sig'])) ."</TD>
</TR>
<TR>
   <TD COLSPAN=2>". _USER_PROF .":<BR>
   ". $out->textarea("profile",8,$size['text'],KWL_PrepareHtml($user['profile'])) ."</TD>
</TR>
<TR>
   <TD COLSPAN=2>"
   . $out->input_form("HIDDEN","what","infochange")
   . $out->input_form("HIDDEN","uid",$user['uid'])
   . $out->input_form("HIDDEN","hcode",KWL_HcodeMake($user['uid']."infochange"))
   . $out->input_form("SUBMIT",'',_SAVE_CHANGE) ."</TD>
</TR>". $out->table_end() . $out->form_end();
KWL_DrawMain($VAR);

$VAR['Heading'] = _PASSWD;
$VAR['Content'] = $out->form_start("user.php","change")
. $out->table_start("100%",'',0,0,3) ."
<TR>
   <TD COLSPAN=2>
   ". _NEW_PASS ."<BR>"
   . $out->input_form("password","pass1",'',KWL_FormSize(7),13) ." (". _PASSAGAIN .") "
   . $out->input_form("password","pass2",'',KWL_FormSize(7),13) ."</TD>
</TR>
<TR>
   <TD COLSPAN=2>"
   . $out->input_form("HIDDEN","what","passchange")
   . $out->input_form("HIDDEN","uid",$user['uid'])
   . $out->input_form("HIDDEN","hcode",KWL_HcodeMake($user['uid']."passchange"))
   . $out->input_form("SUBMIT",'',_SAVE_CHANGE) ."</TD>
</TR>". $out->table_end() . $out->form_end();
KWL_DrawMain($VAR);
include("include/footer.inc.php");
}
?>

==> korweblog-1.5.9.tar.gz: korweblog-1.5.9/user.php <==
<?
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001-2004 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

include ("include/common.inc.php");
include ("include/posted.inc.php");

$check = array("infochange","mark","bmark","logout","passchange");
if (!isset($_COOKIE['kwebloguser']) || !$login) {
   if (in_array($what, $check)) KWL_ShowError(_USER_ONLY);
   KWL_Redirect("login.php");
}

if ($CONF['User_list']) {
   include("$CONF[G_PATH]/include/kmod/user_list/index.php");
}

$out = new KWL_Html;
settype($what, "string");
switch ($what) {
   
   case "infochange":
      if (KWL_HcodeCheck($uid.$what,$hcode)) {
         $email = KWL_EmailCheck($email);
         if (!$email) KWL_ShowError(_HID);
         $url = KWL_UrlCheck($url);
         $sig = trim($sig);
         $profile = trim($profile);
         $sql = "UPDATE T_Users SET email = '$email' , url = '$url', user_sig = '$sig' , profile = '$profile' WHERE uid = '$uid'";
         if (SqlQuery($sql)) KWL_Redirect("user.php",1);
         else KWL_ShowError(_SQL_ERROR);
      } else KWL_ShowError(_SQL_ERROR);
   break;

   case "mark":
      if ($rid) {
         if (KWL_BookmarkSave($user['uid'],$rid)) KWL_ShowError(_BOOKMARK_SAVED);
         else KWL_ShowError(_BOOKMARK_ERROR);
      } else KWL_Redirect("login.php");
   break;

   case "bmark":
      if (isset($delid)) {
         $sql = "DELETE FROM T_UBookmark WHERE id='$delid'";
         if (SqlQuery($sql)) $msg = _BOOKMARK_DELETED;
         else  $msg = _SQL_ERROR;
      }
      include("include/header.inc.php");
      KWL_UserNavig();
      unset($VAR);
      $result = KWL_BookmarkList($user['uid'],1);
      $VAR['Content'] = "<br />". $out->table_start("100%");
      if (mysql_num_rows($result)) {
         $num = 1;
         while ($A = mysql_fetch_array($result)) {
            if ($A['pid'] == "story") $sql = "SELECT Rid,Heading,Author,Birthstamp FROM T_Stories ";
            else $sql = "SELECT Content,Author,Birthstamp FROM T_Comments ";
            $sql .= "WHERE Rid='$A[rid]'";
            $C = SqlQueryFetchArray($sql);
            
            $VAR['Content'] .= "<tr><td>$num. ";
            if (is_array($C)) {
               if ($C['Author'] == "Anonymous") $C['Author'] = _ANONY;
               if ($A['pid'] == "story") {
                  $VAR['Content'] .= "<a href=\"". KWL_MakeStoryLink($A['rid']) ."\">$C[Heading]</a>";
               } else {
                  $VAR['Content'] .= "<a href=\"comments.php?rid=$A[pid]&amp;bid=$A[rid]&amp;bm=1#$A[rid]\">". KWL_PrepareHtml(KWL_StringCut($C['Content'],50)) . "...</a>";
               }
               $VAR['Content'] .= " - $C[Author] (" .
                                  KWL_DateFormat($C['Birthstamp'],"%b-%d %I:%M %p") .")";
            } else $VAR['Content'] .= _REPLY_DELETED;
            $VAR['Content'] .= "</td><td align=\"center\"><a href=\"user.php?what=bmark&amp;delid=$A[id]\">". _BOOKMARK_DEL ."</a></td></tr>\n";
            $num++;
         }
         
      } else $VAR['Content'] .= "<tr><td>". _NO_BOOKMARK ."</td></tr>";
      $VAR['Content'] .= "<tr><td colspan=\"2\" align=\"center\"><hr size=\"1\" width=\"80%\" noshade=\"noshade\" />" . sprintf(_BOOKMARK_NUM,$CONF['Bmark_limit']) ."</td></tr>". $out->table_end();
      $VAR['Heading'] = _BOOKMARK;
      KWL_DrawMain($VAR);
      include("include/footer.inc.php");
      exit;
   break;

   case "logout":
      setcookie("kwebloguser","");
      KWL_RedirectNotice(sprintf(_START_LOGOUT,$user['name']),"$CONF[G_URL]",1);
   break;

   case "passchange":
      if (!empty($pass1) && !empty($pass2) && KWL_HcodeCheck($uid.$what,$hcode)) {
         if ($pass1 == $pass2) {
            $cpass = crypt($pass1);
            $sql = "UPDATE T_Users SET pass = '$cpass' WHERE uid = '$uid'";
            if (SqlQuery($sql)) {
               setcookie("kwebloguser","");
               KWL_RedirectNotice(sprintf(_PASS_CHANGED,$user['name']),"login.php",3);
            } else KWL_ShowError(_SQL_ERROR);
         } else KWL_ShowError(_NO_CHANGE);
      } else KWL_ShowError(_NO_CHANGE);
   break;

   case "userlist":
      if ($CONF['User_list']) {
         include("include/header.inc.php");
         KWL_UserNavig();
         settype($index, "string");
         settype($where, "string");
         KWL_UserList($index,"$CONF[G_URL]/user.php?what=userlist&index=$index",$where,$out);
         include("include/footer.inc.php");
         exit;
      } else KWL_ShowError(_DISABLED);
   break;

   case "mypost":
      include("include/header.inc.php");
      KWL_UserNavig();
      $my = new KWL_MyPost;
      $my->my_story($user['name'],$user['email'],$out);
      $my->my_reply($user['name'],$user['email'],$out);
      include("include/footer.inc.php");
      exit;
   break;

   default: 

$head = _UHOME;
include("include/header.inc.php");
KWL_UserNavig();
$VAR['Heading'] = _USER_INFO;
$VAR['Content'] = $out->form_start("user.php","change")
. $out->table_start("100%",'',0,0,3) ."
<tr>
   <td>". _NAME .": </td>
   <td><a href=\"profiles.php?uid=$user[uid]\">$user[name]</a> (#$user[uid])</td>
</tr>
<tr>
   <td>". _EMAIL .": </td>
   <td>". $out->input_form("text","email",$user['email'],KWL_FormSize(10),60) ."</td>
</tr>
<tr>
   <td>". _URL .": </td>
   <td>". $out->input_form("text","url",$user['url'],KWL_FormSize(15),100) ."</td>
</tr>
<tr>
   <td>". _RDATE .": </td>
   <td>$user[rdate]</td>
</tr>
<tr>
   <td colspan=\"2\">". _USER_SIG .":<br />
   ". $out->textarea("sig",4,$size['text'],KWL_PrepareHtml($user['user_sig'])) ."</td>
</tr>
<tr>
   <td colspan=\"2\">". _USER_PROF .":<br />
   ". $out->textarea("profile",8,$size['text'],KWL_PrepareHtml($user['profile'])) ."</td>
</tr>
<tr>
   <td colspan=\"2\">"
   . $out->input_form("hidden","what","infochange")
   . $out->input_form("hidden","uid",$user['uid'])
   . $out->input_form("hidden","hcode",KWL_HcodeMake($user['uid']."infochange"))
   . $out->input_form("submit",'',_SAVE_CHANGE) ."</td>
</tr>". $out->table_end() . $out->form_end();
KWL_DrawMain($VAR);

$VAR['Heading'] = _PASSWD;
$VAR['Content'] = $out->form_start("user.php","change")
. $out->table_start("100%",'',0,0,3) ."
<tr>
   <td colspan=\"2\">
   ". _NEW_PASS ."<br />"
   . $out->input_form("password","pass1",'',KWL_FormSize(7),13) ." (". _PASSAGAIN .") "
   . $out->input_form("password","pass2",'',KWL_FormSize(7),13) ."</td>
</tr>
<tr>
   <td colspan=\"2\">"
   . $out->input_form("hidden","what","passchange")
   . $out->input_form("hidden","uid",$user['uid'])
   . $out->input_form("hidden","hcode",KWL_HcodeMake($user['uid']."passchange"))
   . $out->input_form("submit",'',_SAVE_CHANGE) ."</td>
</tr>". $out->table_end() . $out->form_end();
KWL_DrawMain($VAR);
include("include/footer.inc.php");
}
?>
